searchData={"items":[{"type":"module","title":"Crontab.CronExpression","doc":"The `Crontab.CronExpression` module / struct.","ref":"Crontab.CronExpression.html"},{"type":"function","title":"Crontab.CronExpression.__struct__/0","doc":"Defines the Cron interval.\n\n    * * * * * * *\n    | | | | | | |\n    | | | | | | +-- :year Year                 (range: 1900-3000)\n    | | | | | +---- :weekday Day of the Week   (range: 1-7, 1 standing for Monday)\n    | | | | +------ :month Month of the Year   (range: 1-12)\n    | | | +-------- :day Day of the Month      (range: 1-31)\n    | | +---------- :hour Hour                 (range: 0-23)\n    | +------------ :minute Minute             (range: 0-59)\n    +-------------- :second Second             (range: 0-59)\n\nThe `:extended` attribute defines if the second is taken into account.","ref":"Crontab.CronExpression.html#__struct__/0"},{"type":"function","title":"Crontab.CronExpression.sigil_e/2","doc":"Create a `%Crontab.CronExpression{}` via sigil.","ref":"Crontab.CronExpression.html#sigil_e/2"},{"type":"function","title":"Examples - Crontab.CronExpression.sigil_e/2","doc":"iex> ~e[*]\n    %Crontab.CronExpression{\n      extended: false,\n      second: [:*],\n      minute: [:*],\n      hour: [:*],\n      day: [:*],\n      month: [:*],\n      weekday: [:*],\n      year: [:*]}\n\n    iex> ~e[*]e\n    %Crontab.CronExpression{\n      extended: true,\n      second: [:*],\n      minute: [:*],\n      hour: [:*],\n      day: [:*],\n      month: [:*],\n      weekday: [:*],\n      year: [:*]}\n\n    iex> ~e[1 2 3 4 5 6 7]e\n    %Crontab.CronExpression{\n      extended: true,\n      second: [1],\n      minute: [2],\n      hour: [3],\n      day: [4],\n      month: [5],\n      weekday: [6],\n      year: [7]}","ref":"Crontab.CronExpression.html#sigil_e/2-examples"},{"type":"function","title":"Crontab.CronExpression.to_condition_list/1","doc":"Convert `Crontab.CronExpression` struct to tuple List.","ref":"Crontab.CronExpression.html#to_condition_list/1"},{"type":"function","title":"Examples - Crontab.CronExpression.to_condition_list/1","doc":"iex> Crontab.CronExpression.to_condition_list %Crontab.CronExpression{\n    ...> minute: [1], hour: [2], day: [3], month: [4], weekday: [5], year: [6]}\n    [ {:minute, [1]},\n      {:hour, [2]},\n      {:day, [3]},\n      {:month, [4]},\n      {:weekday, [5]},\n      {:year, [6]}]\n\n    iex> Crontab.CronExpression.to_condition_list %Crontab.CronExpression{\n    ...> extended: true, second: [0], minute: [1], hour: [2], day: [3], month: [4], weekday: [5], year: [6]}\n    [ {:second, [0]},\n      {:minute, [1]},\n      {:hour, [2]},\n      {:day, [3]},\n      {:month, [4]},\n      {:weekday, [5]},\n      {:year, [6]}]","ref":"Crontab.CronExpression.html#to_condition_list/1-examples"},{"type":"type","title":"Crontab.CronExpression.condition/0","doc":"","ref":"Crontab.CronExpression.html#t:condition/0"},{"type":"type","title":"Crontab.CronExpression.condition/2","doc":"","ref":"Crontab.CronExpression.html#t:condition/2"},{"type":"type","title":"Crontab.CronExpression.condition_list/0","doc":"","ref":"Crontab.CronExpression.html#t:condition_list/0"},{"type":"type","title":"Crontab.CronExpression.day/0","doc":"","ref":"Crontab.CronExpression.html#t:day/0"},{"type":"type","title":"Crontab.CronExpression.hour/0","doc":"","ref":"Crontab.CronExpression.html#t:hour/0"},{"type":"type","title":"Crontab.CronExpression.interval/0","doc":"","ref":"Crontab.CronExpression.html#t:interval/0"},{"type":"type","title":"Crontab.CronExpression.min_max/0","doc":"","ref":"Crontab.CronExpression.html#t:min_max/0"},{"type":"type","title":"Crontab.CronExpression.min_max/1","doc":"","ref":"Crontab.CronExpression.html#t:min_max/1"},{"type":"type","title":"Crontab.CronExpression.minute/0","doc":"","ref":"Crontab.CronExpression.html#t:minute/0"},{"type":"type","title":"Crontab.CronExpression.month/0","doc":"","ref":"Crontab.CronExpression.html#t:month/0"},{"type":"type","title":"Crontab.CronExpression.second/0","doc":"","ref":"Crontab.CronExpression.html#t:second/0"},{"type":"type","title":"Crontab.CronExpression.t/0","doc":"","ref":"Crontab.CronExpression.html#t:t/0"},{"type":"type","title":"Crontab.CronExpression.time_unit/0","doc":"","ref":"Crontab.CronExpression.html#t:time_unit/0"},{"type":"type","title":"Crontab.CronExpression.value/0","doc":"","ref":"Crontab.CronExpression.html#t:value/0"},{"type":"type","title":"Crontab.CronExpression.value/1","doc":"","ref":"Crontab.CronExpression.html#t:value/1"},{"type":"type","title":"Crontab.CronExpression.weekday/0","doc":"","ref":"Crontab.CronExpression.html#t:weekday/0"},{"type":"type","title":"Crontab.CronExpression.year/0","doc":"","ref":"Crontab.CronExpression.html#t:year/0"},{"type":"module","title":"Crontab.CronExpression.Composer","doc":"Generate from `%CronExpression{}` to `* * * * * *`.","ref":"Crontab.CronExpression.Composer.html"},{"type":"function","title":"Crontab.CronExpression.Composer.compose/1","doc":"Generate from `%Crontab.CronExpression{}` to `* * * * * *`.","ref":"Crontab.CronExpression.Composer.html#compose/1"},{"type":"function","title":"Examples - Crontab.CronExpression.Composer.compose/1","doc":"iex> Crontab.CronExpression.Composer.compose %Crontab.CronExpression{}\n    \"* * * * * *\"\n\n    iex> Crontab.CronExpression.Composer.compose %Crontab.CronExpression{minute: [9, {:-, 4, 6}, {:/, :*, 9}]}\n    \"9,4-6,*/9 * * * * *\"\n\n    iex> Crontab.CronExpression.Composer.compose %Crontab.CronExpression{reboot: true}\n    \"@reboot\"","ref":"Crontab.CronExpression.Composer.html#compose/1-examples"},{"type":"module","title":"Crontab.CronExpression.Ecto.Type","doc":"Provides a type for Ecto usage.\n\nThe underlying data type should be a map.","ref":"Crontab.CronExpression.Ecto.Type.html"},{"type":"module","title":"Migration Example - Crontab.CronExpression.Ecto.Type","doc":"create table(:my_table) do\n      add :schedule, :map\n    end","ref":"Crontab.CronExpression.Ecto.Type.html#module-migration-example"},{"type":"module","title":"Schema Example - Crontab.CronExpression.Ecto.Type","doc":"schema \"my_table\" do\n      field :schedule, Crontab.CronExpression.Ecto.Type\n    end","ref":"Crontab.CronExpression.Ecto.Type.html#module-schema-example"},{"type":"function","title":"Crontab.CronExpression.Ecto.Type.cast/1","doc":"","ref":"Crontab.CronExpression.Ecto.Type.html#cast/1"},{"type":"function","title":"Crontab.CronExpression.Ecto.Type.dump/1","doc":"","ref":"Crontab.CronExpression.Ecto.Type.html#dump/1"},{"type":"function","title":"Crontab.CronExpression.Ecto.Type.embed_as/1","doc":"","ref":"Crontab.CronExpression.Ecto.Type.html#embed_as/1"},{"type":"function","title":"Crontab.CronExpression.Ecto.Type.equal?/2","doc":"","ref":"Crontab.CronExpression.Ecto.Type.html#equal?/2"},{"type":"function","title":"Crontab.CronExpression.Ecto.Type.load/1","doc":"","ref":"Crontab.CronExpression.Ecto.Type.html#load/1"},{"type":"function","title":"Crontab.CronExpression.Ecto.Type.type/0","doc":"","ref":"Crontab.CronExpression.Ecto.Type.html#type/0"},{"type":"type","title":"Crontab.CronExpression.Ecto.Type.map_expression/0","doc":"","ref":"Crontab.CronExpression.Ecto.Type.html#t:map_expression/0"},{"type":"module","title":"Crontab.CronExpression.Parser","doc":"Parse string like `* * * * * *` to a `%Crontab.CronExpression{}`.","ref":"Crontab.CronExpression.Parser.html"},{"type":"function","title":"Crontab.CronExpression.Parser.parse/2","doc":"Parse string like `* * * * * *` to a `%CronExpression{}`.","ref":"Crontab.CronExpression.Parser.html#parse/2"},{"type":"function","title":"Examples - Crontab.CronExpression.Parser.parse/2","doc":"iex> Crontab.CronExpression.Parser.parse \"* * * * *\"\n    {:ok,\n      %Crontab.CronExpression{day: [:*], hour: [:*], minute: [:*],\n      month: [:*], weekday: [:*], year: [:*]}}\n\n    iex> Crontab.CronExpression.Parser.parse \"* * * * *\", true\n    {:ok,\n      %Crontab.CronExpression{extended: true, day: [:*], hour: [:*], minute: [:*],\n      month: [:*], weekday: [:*], year: [:*], second: [:*]}}\n\n    iex> Crontab.CronExpression.Parser.parse \"fooo\"\n    {:error, \"Can't parse fooo as minute.\"}","ref":"Crontab.CronExpression.Parser.html#parse/2-examples"},{"type":"function","title":"Crontab.CronExpression.Parser.parse!/2","doc":"Parse string like `* * * * * *` to a `%CronExpression{}`.","ref":"Crontab.CronExpression.Parser.html#parse!/2"},{"type":"function","title":"Examples - Crontab.CronExpression.Parser.parse!/2","doc":"iex> Crontab.CronExpression.Parser.parse! \"* * * * *\"\n    %Crontab.CronExpression{day: [:*], hour: [:*], minute: [:*],\n      month: [:*], weekday: [:*], year: [:*]}\n\n    iex> Crontab.CronExpression.Parser.parse! \"* * * * *\", true\n    %Crontab.CronExpression{extended: true, day: [:*], hour: [:*], minute: [:*],\n      month: [:*], weekday: [:*], year: [:*], second: [:*]}\n\n    iex> Crontab.CronExpression.Parser.parse! \"fooo\"\n    ** (RuntimeError) Can't parse fooo as minute.","ref":"Crontab.CronExpression.Parser.html#parse!/2-examples"},{"type":"type","title":"Crontab.CronExpression.Parser.result/0","doc":"","ref":"Crontab.CronExpression.Parser.html#t:result/0"},{"type":"module","title":"Crontab.DateChecker","doc":"This module is used to check a `Crontab.CronExpression` against a given date.","ref":"Crontab.DateChecker.html"},{"type":"function","title":"Crontab.DateChecker.matches_date?/2","doc":"Check a condition list against a given date.","ref":"Crontab.DateChecker.html#matches_date?/2"},{"type":"function","title":"Examples - Crontab.DateChecker.matches_date?/2","doc":"iex> Crontab.DateChecker.matches_date? %Crontab.CronExpression{minute: [{:\"/\", :*, 8}]}, ~N[2004-04-16 04:08:08]\n    true\n\n    iex> Crontab.DateChecker.matches_date? %Crontab.CronExpression{minute: [{:\"/\", :*, 9}]}, ~N[2004-04-16 04:07:08]\n    false\n\n    iex> Crontab.DateChecker.matches_date? %Crontab.CronExpression{reboot: true}, ~N[2004-04-16 04:07:08]\n    ** (RuntimeError) Special identifier @reboot is not supported.\n\n    iex> Crontab.DateChecker.matches_date? [{:hour, [{:\"/\", :*, 4}, 7]}], ~N[2004-04-16 04:07:08]\n    true","ref":"Crontab.DateChecker.html#matches_date?/2-examples"},{"type":"function","title":"Crontab.DateChecker.matches_date?/3","doc":"Check a condition against a given date.","ref":"Crontab.DateChecker.html#matches_date?/3"},{"type":"function","title":"Examples - Crontab.DateChecker.matches_date?/3","doc":"iex> Crontab.DateChecker.matches_date? :hour, [{:\"/\", :*, 4}, 7], ~N[2004-04-16 04:07:08]\n    true\n\n    iex> Crontab.DateChecker.matches_date? :hour, [8], ~N[2004-04-16 04:07:08]\n    false","ref":"Crontab.DateChecker.html#matches_date?/3-examples"},{"type":"type","title":"Crontab.DateChecker.date/0","doc":"","ref":"Crontab.DateChecker.html#t:date/0"},{"type":"module","title":"Crontab.Scheduler","doc":"This module provides the functionality to retrieve the next run date or the\nprevious run date from a `%CronExpression{}`.","ref":"Crontab.Scheduler.html"},{"type":"function","title":"Crontab.Scheduler.get_next_run_date/3","doc":"This function provides the functionality to retrieve the next run date from a\n`%Crontab.CronExpression{}`.","ref":"Crontab.Scheduler.html#get_next_run_date/3"},{"type":"function","title":"Examples - Crontab.Scheduler.get_next_run_date/3","doc":"iex> Crontab.Scheduler.get_next_run_date(%Crontab.CronExpression{}, ~N[2002-01-13 23:00:07])\n    {:ok, ~N[2002-01-13 23:01:00]}\n\n    iex> Crontab.Scheduler.get_next_run_date(%Crontab.CronExpression{year: [{:/, :*, 9}]}, ~N[2002-01-13 23:00:07])\n    {:ok, ~N[2007-01-01 00:00:00]}\n\n    iex> Crontab.Scheduler.get_next_run_date %Crontab.CronExpression{reboot: true}\n    ** (RuntimeError) Special identifier @reboot is not supported.","ref":"Crontab.Scheduler.html#get_next_run_date/3-examples"},{"type":"function","title":"Crontab.Scheduler.get_next_run_date!/3","doc":"This function provides the functionality to retrieve the next run date from a\n`%Crontab.CronExpression{}`.","ref":"Crontab.Scheduler.html#get_next_run_date!/3"},{"type":"function","title":"Examples - Crontab.Scheduler.get_next_run_date!/3","doc":"iex> Crontab.Scheduler.get_next_run_date!(%Crontab.CronExpression{}, ~N[2002-01-13 23:00:07])\n    ~N[2002-01-13 23:01:00]\n\n    iex> Crontab.Scheduler.get_next_run_date!(%Crontab.CronExpression{year: [1990]}, ~N[2002-01-13 23:00:07])\n    ** (RuntimeError) No compliant date was found for your interval.\n\n    iex> Crontab.Scheduler.get_next_run_date!(%Crontab.CronExpression{year: [{:/, :*, 9}]}, ~N[2002-01-13 23:00:07])\n    ~N[2007-01-01 00:00:00]\n\n    iex> Crontab.Scheduler.get_next_run_date! %Crontab.CronExpression{reboot: true}\n    ** (RuntimeError) Special identifier @reboot is not supported.","ref":"Crontab.Scheduler.html#get_next_run_date!/3-examples"},{"type":"function","title":"Crontab.Scheduler.get_next_run_dates/2","doc":"Find the next execution dates relative to a given date from a `%CronExpression{}`.","ref":"Crontab.Scheduler.html#get_next_run_dates/2"},{"type":"function","title":"Examples - Crontab.Scheduler.get_next_run_dates/2","doc":"iex> Enum.take(Crontab.Scheduler.get_next_run_dates(\n    ...>  %Crontab.CronExpression{extended: true}, ~N[2016-12-17 00:00:00]), 3)\n    [\n      ~N[2016-12-17 00:00:00],\n      ~N[2016-12-17 00:00:01],\n      ~N[2016-12-17 00:00:02]\n    ]\n\n    iex> Enum.take(Crontab.Scheduler.get_next_run_dates(%Crontab.CronExpression{}, ~N[2016-12-17 00:00:00]), 3)\n    [\n      ~N[2016-12-17 00:00:00],\n      ~N[2016-12-17 00:01:00],\n      ~N[2016-12-17 00:02:00]\n    ]\n\n    iex> Enum.take(Crontab.Scheduler.get_next_run_dates(%Crontab.CronExpression{\n    ...>   year: [2017], month: [1], day: [1], hour: [0], minute: [1]}, ~N[2016-12-17 00:00:00]), 3)\n    [~N[2017-01-01 00:01:00]]\n\n    iex> Enum.take(Crontab.Scheduler.get_next_run_dates(%Crontab.CronExpression{reboot: true}), 3)\n    ** (RuntimeError) Special identifier @reboot is not supported.","ref":"Crontab.Scheduler.html#get_next_run_dates/2-examples"},{"type":"function","title":"Crontab.Scheduler.get_previous_run_date/3","doc":"This function provides the functionality to retrieve the previous run date\nfrom a `%Crontab.CronExpression{}`.","ref":"Crontab.Scheduler.html#get_previous_run_date/3"},{"type":"function","title":"Examples - Crontab.Scheduler.get_previous_run_date/3","doc":"iex> Crontab.Scheduler.get_previous_run_date %Crontab.CronExpression{}, ~N[2002-01-13 23:00:07]\n    {:ok, ~N[2002-01-13 23:00:00]}\n\n    iex> Crontab.Scheduler.get_previous_run_date %Crontab.CronExpression{\n    ...> year: [{:/, :*, 9}]}, ~N[2002-01-13 23:00:07]\n    {:ok, ~N[1998-12-31 23:59:00]}\n\n    iex> Crontab.Scheduler.get_previous_run_date %Crontab.CronExpression{reboot: true}\n    ** (RuntimeError) Special identifier @reboot is not supported.","ref":"Crontab.Scheduler.html#get_previous_run_date/3-examples"},{"type":"function","title":"Crontab.Scheduler.get_previous_run_date!/3","doc":"This function provides the functionality to retrieve the previous run date\nfrom a `%Crontab.CronExpression{}`.","ref":"Crontab.Scheduler.html#get_previous_run_date!/3"},{"type":"function","title":"Examples - Crontab.Scheduler.get_previous_run_date!/3","doc":"iex> Crontab.Scheduler.get_previous_run_date! %Crontab.CronExpression{}, ~N[2002-01-13 23:00:07]\n    ~N[2002-01-13 23:00:00]\n\n    iex> Crontab.Scheduler.get_previous_run_date!(%Crontab.CronExpression{year: [2100]}, ~N[2002-01-13 23:00:07])\n    ** (RuntimeError) No compliant date was found for your interval.\n\n    iex> Crontab.Scheduler.get_previous_run_date! %Crontab.CronExpression{\n    ...> year: [{:/, :*, 9}]}, ~N[2002-01-13 23:00:07]\n    ~N[1998-12-31 23:59:00]\n\n    iex> Crontab.Scheduler.get_previous_run_date! %Crontab.CronExpression{reboot: true}\n    ** (RuntimeError) Special identifier @reboot is not supported.","ref":"Crontab.Scheduler.html#get_previous_run_date!/3-examples"},{"type":"function","title":"Crontab.Scheduler.get_previous_run_dates/2","doc":"Find the previous n execution dates relative to a given date from a `%CronExpression{}`.","ref":"Crontab.Scheduler.html#get_previous_run_dates/2"},{"type":"function","title":"Examples - Crontab.Scheduler.get_previous_run_dates/2","doc":"iex> Enum.take(Crontab.Scheduler.get_previous_run_dates(\n    ...>   %Crontab.CronExpression{extended: true}, ~N[2016-12-17 00:00:00]), 3)\n    [\n      ~N[2016-12-17 00:00:00],\n      ~N[2016-12-16 23:59:59],\n      ~N[2016-12-16 23:59:58]\n    ]\n\n    iex> Enum.take(Crontab.Scheduler.get_previous_run_dates(%Crontab.CronExpression{}, ~N[2016-12-17 00:00:00]), 3)\n    [\n      ~N[2016-12-17 00:00:00],\n      ~N[2016-12-16 23:59:00],\n      ~N[2016-12-16 23:58:00]\n    ]\n\n    iex> Enum.take(Crontab.Scheduler.get_previous_run_dates(%Crontab.CronExpression{\n    ...>   year: [2017], month: [1], day: [1], hour: [0], minute: [1]}, ~N[2016-12-17 00:00:00]), 3)\n    []\n\n    iex> Enum.take(Crontab.Scheduler.get_previous_run_dates(%Crontab.CronExpression{reboot: true}), 3)\n    ** (RuntimeError) Special identifier @reboot is not supported.","ref":"Crontab.Scheduler.html#get_previous_run_dates/2-examples"},{"type":"type","title":"Crontab.Scheduler.direction/0","doc":"","ref":"Crontab.Scheduler.html#t:direction/0"},{"type":"type","title":"Crontab.Scheduler.result/0","doc":"","ref":"Crontab.Scheduler.html#t:result/0"},{"type":"extras","title":"Crontab","doc":"# Crontab\n\n[![CI](https://github.com/jshmrtn/crontab/workflows/.github/workflows/elixir.yml/badge.svg)](https://github.com/jshmrtn/crontab/actions?query=workflow%3A.github%2Fworkflows%2Felixir.yml)\n[![Coverage Status](https://coveralls.io/repos/github/jshmrtn/crontab/badge.svg?branch=main)](https://coveralls.io/github/jshmrtn/crontab?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/crontab.svg)](https://hex.pm/packages/crontab)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/crontab/)\n[![Total Download](https://img.shields.io/hexpm/dt/crontab.svg)](https://hex.pm/packages/crontab)\n[![License](https://img.shields.io/hexpm/l/crontab.svg)](https://github.com/jshmrtn/crontab/blob/main/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/jshmrtn/crontab.svg)](https://github.com/jshmrtn/crontab/commits/main)\n\nElixir library for parsing, writing, and calculating Cron format strings.","ref":"readme.html"},{"type":"extras","title":"Installation - Crontab","doc":"Add `:crontab` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:crontab, \"~> 1.1\"}\n  ]\nend\n```\n\nFor Elixir version before 1.4, ensure `:crontab` is started before your\napplication:\n\n```elixir\ndef application do\n  [\n    applications: [:crontab]\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Crontab","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Import Cron expression sigil - Crontab","doc":"Everywhere you want to use the Cron expression sigil (`e[cron expression]`).\n\n```elixir\nimport Crontab.CronExpression\n```","ref":"readme.html#import-cron-expression-sigil"},{"type":"extras","title":"Extended Cron expressions - Crontab","doc":"An extended Cron expression has more precision than a normal Cron expression.\nIt also specifies the second.\n\nIf you want to use extended Cron expressions with the sigil, just append an `e`.","ref":"readme.html#extended-cron-expressions"},{"type":"extras","title":"Checking if a Cron Expression Matches a date - Crontab","doc":"```elixir\niex> import Crontab.CronExpression\niex> Crontab.DateChecker.matches_date?(~e[*/2], ~N[2017-01-01 01:01:00])\nfalse\niex> Crontab.DateChecker.matches_date?(~e[*], ~N[2017-01-01 01:01:00])\ntrue\n```","ref":"readme.html#checking-if-a-cron-expression-matches-a-date"},{"type":"extras","title":"Find Next / Previous Execution Date candidates - Crontab","doc":"All the date parameters default to now.\n\nFor previous, just replace `next` in the code below.\n\n```elixir\niex> import Crontab.CronExpression\niex> Crontab.Scheduler.get_next_run_date(~e[*/2], ~N[2017-01-01 01:01:00])\n{:ok, ~N[2017-01-01 01:02:00]}\niex> Crontab.Scheduler.get_next_run_date!(~e[*/2], ~N[2017-01-01 01:01:00])\n~N[2017-01-01 01:02:00]\n```\n\n```elixir\niex> Crontab.Scheduler.get_next_run_dates(3, ~e[*/2], ~N[2017-01-01 01:01:00])\n{:ok,\n [~N[2017-01-01 01:02:00], ~N[2017-01-01 01:04:00], ~N[2017-01-01 01:06:00]]}\niex> Crontab.Scheduler.get_next_run_dates!(3, ~e[*/2], ~N[2017-01-01 01:01:00])\n[~N[2017-01-01 01:02:00], ~N[2017-01-01 01:04:00], ~N[2017-01-01 01:06:00]]\n```","ref":"readme.html#find-next-previous-execution-date-candidates"},{"type":"extras","title":"Parse Cron Expressions - Crontab","doc":"If you statically define cron expressions, use the `~e[cron expression]` sigil.\n\nFor dynamic cron expressions, there is a Parser module.\n\nThe parser module takes an optional `extended` flag. This is to mark if the\nexpression contains seconds. This defaults to `false`.\n\n```elixir\niex> Crontab.CronExpression.Parser.parse \"* * * * *\"\n{:ok,\n  %Crontab.CronExpression{day: [:*], hour: [:*], minute: [:*],\n  month: [:*], weekday: [:*], year: [:*]}}\niex> Crontab.CronExpression.Parser.parse! \"* * * * *\"\n%Crontab.CronExpression{day: [:*], hour: [:*], minute: [:*],\n month: [:*], weekday: [:*], year: [:*]}\n```","ref":"readme.html#parse-cron-expressions"},{"type":"extras","title":"Compose Cron expressions - Crontab","doc":"```elixir\niex> Crontab.CronExpression.Composer.compose %Crontab.CronExpression{}\n\"* * * * * *\"\niex> Crontab.CronExpression.Composer.compose %Crontab.CronExpression{minute: [9, {:-, 4, 6}, {:/, :*, 9}]}\n\"9,4-6,*/9 * * * * *\"\n```","ref":"readme.html#compose-cron-expressions"},{"type":"extras","title":"Copyright and License - Crontab","doc":"Copyright (c) 2016, SK & T AG, JOSHMARTIN GmbH, Jonatan Männchen\n\nThis library is MIT licensed. See the [LICENSE](https://github.com/jshmrtn/crontab/blob/main/LICENSE) for details.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Cron Notation Cheatsheet","doc":"# Cron Notation Cheatsheet","ref":"cron_notation.html"},{"type":"extras","title":"Overview - Cron Notation Cheatsheet","doc":"```\n[:second] :minute :hour :day :month :weekday :year\n```\n\n```\n   [*]       *      *     *     *       *      *\n```\n\n```\n    |        |      |     |     |       |      |\n    |        |      |     |     |       |      └-- Year              (range: 1900-3000)\n    |        |      |     |     |       └--------- Day of the Week   (range: 0-7, 0 sunday, 1 monday, ..., 7 sunday)\n    |        |      |     |     └----------------- Month of the Year (range: 1-12)\n    |        |      |     └----------------------- Day of the Month  (range: 1-31)\n    |        |      └----------------------------- Hour              (range: 0-23)\n    |        └------------------------------------ Minute            (range: 0-59)\n    └--------------------------------------------- Second            (range: 0-59)\n```\n\nSeconds are only present in a cron expression if `extended` is enabled.","ref":"cron_notation.html#overview"},{"type":"extras","title":"Operators - Cron Notation Cheatsheet","doc":"| Operator | Description                                                  | Allowed in        |\n| -------- | ------------------------------------------------------------ | ----------------- |\n| `*`      | all values                                                   | everywhere        |\n| `,`      | separate individual values                                   | everywhere        |\n| `-`      | a range of values                                            | everywhere        |\n| `/`      | divide a value into steps                                    | everywhere        |\n| `#`      | nth occurance                                                | `weekday`         |\n| `L`      | last occurance                                               | `weekday` / `day` |\n| `W`      | specifies the `weekday` nearest the given `day` of the month | `day`             |\n| `LW`     | last `weekday` of the month                                  | `day`             |","ref":"cron_notation.html#operators"},{"type":"extras","title":"Expressions - Cron Notation Cheatsheet","doc":"{: .col-2}","ref":"cron_notation.html#expressions"},{"type":"extras","title":"Special Values - Cron Notation Cheatsheet","doc":"{: .list-4}\n\n#### Days\n\nspecify a day by name in the `weekday` field\n\n- `MON`\n- `TUE`\n- `WED`\n- `THU`\n- `FRI`\n- `SAT`\n- `SUN`\n\n#### Months\n\nspecify a month by name in the `month` field\n\n- `JAN`\n- `FEB`\n- `MAR`\n- `APR`\n- `MAY`\n- `JUN`\n- `JUL`\n- `AUG`\n- `SEP`\n- `OCT`\n- `NOV`\n- `DEC`","ref":"cron_notation.html#special-values"},{"type":"extras","title":"Special Expressions - Cron Notation Cheatsheet","doc":"| Expression  | Description                               |\n| ----------- | ----------------------------------------- |\n| `@reboot`   | once after start of application           |\n| `@yearly`   | once at the start of every year           |\n| `@annually` | same as `@yearly`                         |\n| `@monthly`  | once at the start of every month          |\n| `@weekly`   | once at the start of every week on sunday |\n| `@dayily`   | once at the start of every day            |\n| `@midnight` | same as `@daily`                          |\n| `@hourly`   | once at the start of every hour           |\n| `@minutely` | once at the start of every minute         |\n| `@secondly` | once at the start of every second         |","ref":"cron_notation.html#special-expressions"},{"type":"extras","title":"Examples - Cron Notation Cheatsheet","doc":"| Expression                 | Description                                                                                                                                                 |\n| -------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------- |\n| `0 0 12 * * *`             | Fire at 12:00 p.m. (noon) every day                                                                                                                         |\n| `0 15 10 * * *`            | Fire at 10:15 a.m. every day                                                                                                                                |\n| `0 15 10 * * *`            | Fire at 10:15 a.m. every day                                                                                                                                |\n| `0 15 10 * * * *`          | Fire at 10:15 a.m. every day                                                                                                                                |\n| `0 15 10 * * * 2012`       | Fire at 10:15 a.m. every day during the year 2012                                                                                                           |\n| `0 * 14 * * *`             | Fire every minute starting at 2:00 p.m. and ending at 2:59.p.m., every day                                                                                  |\n| `0 0/5 14 * * *`           | Fire every five minutes starting at 2:00 p.m. and ending at 2:55 p.m., every day                                                                            |\n| `0 0/5 14,18 * * *`        | Fire every five minutes starting at 2:00 p.m. and ending at 2:55 p.m., and fire every five minutes starting at 6:00 p.m. and ending at 6:55 p.m., every day |\n| `0 0-5 14 * * *`           | Fire every minute starting at 2:00 p.m. and ending at 2:05.p.m., every day                                                                                  |\n| `0 10,44 14 * 3 WED`       | Fire at 2:10 p.m. and at 2:44 p.m. every Wednesday in the month of March                                                                                    |\n| `0 15 10 * * MON-FRI`      | Fire at 10:15 a.m. every Monday, Tuesday, Wednesday, Thursday and Friday                                                                                    |\n| `0 15 10 15 * *`           | Fire at 10:15 a.m. on the 15th day of every month                                                                                                           |\n| `0 15 10 15 * *`           | Fire at 10:15 a.m. on the last day of every month                                                                                                           |\n| `0 15 10 * * 6L`           | Fire at 10:15 a.m. on the last Friday of every month                                                                                                        |\n| `0 15 10 * * 6L 2011-2014` | Fire at 10:15 a.m. on every last Friday of every month during the years 2011, 20012, 2014, and 2014                                                         |\n| `0 15 10 * * 6#3`          | Fire at 10:15 a.m. on the third Friday of every month                                                                                                       |\n| `0 0 12 1/5 * *`           | Fire at 12:00 p.m. (noon) every five days every month, starting on the first day of the month                                                               |\n| `0 11 11 11 11 *`          | Fire every November 11th at 11:11 a.m.                                                                                                                      |","ref":"cron_notation.html#examples"},{"type":"extras","title":"Helpful Tools / further documentation - Cron Notation Cheatsheet","doc":"- [crontab guru](https://crontab.guru/)\n- https://en.wikipedia.org/wiki/Cron\n- https://linux.die.net/man/5/crontab\n- https://www.netiq.com/documentation/cloud-manager-2-5/ncm-reference/data/bexyssf.html\n- http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html\n- https://docs.oracle.com/cd/E12058_01/doc/doc.1014/e12030/cron_expressions.htm","ref":"cron_notation.html#helpful-tools-further-documentation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}